@@ -56,11 +56,9 @@ import traceback
 
 import pytz
 from django.conf import settings
-from django.core.exceptions import ImproperlyConfigured, ObjectDoesNotExist
+from django.core.exceptions import ObjectDoesNotExist
 from django.core.paginator import InvalidPage, QuerySetPaginator
 from django.http import Http404, HttpResponse
-from django.shortcuts import render_to_response
-from django.template.context import RequestContext, Context
 from django.template.defaultfilters import date, timesince
 from django.template.loader import get_template
 from django.utils import six
@@ -1090,10 +1088,10 @@ class DataGrid(object):
         # shrink and expand values.
         colnames = self.request.GET.get('columns', profile_columns_list) or ''
 
-        columns = filter(None, [
+        columns = list(filter(None, [
             self.get_column(colname)
             for colname in colnames.split(',')
-        ])
+        ]))
 
         if not columns:
             colnames = ','.join(self.default_columns)
@@ -1498,7 +1496,8 @@ class DataGrid(object):
         context.update(extra_context)
         context.update(render_context)
 
-        return render_to_response(template_name, Context(context))
+        return HttpResponse(render_to_string(template_name=template_name,
+                                             context=context))
 
     def render_paginator(self, adjacent_pages=3):
         """Render the paginator for the datagrid.
