@@ -26,13 +26,15 @@
 #
 
 from __future__ import unicode_literals
+
 from functools import update_wrapper, wraps
-from inspect import getargspec
 
 from django import template
 from django.template import TemplateSyntaxError, Variable
 from django.utils.functional import cached_property as django_cached_property
 
+from djblets.util.compat.django.utils.inspect import getargspec
+
 
 # The decorator decorator.  This is copyright unknown, verbatim from
 # http://wiki.python.org/moin/PythonDecoratorLibrary
