@@ -26,13 +26,20 @@
 
 from __future__ import unicode_literals
 
+import inspect
 import logging
 
+from django.core.exceptions import ValidationError
 from django.http import HttpRequest
 from django.utils import six
 
 from djblets.webapi.errors import (NOT_LOGGED_IN, PERMISSION_DENIED,
                                    INVALID_FORM_DATA)
+from djblets.webapi.fields import (BooleanFieldType,
+                                   ChoiceFieldType,
+                                   FileFieldType,
+                                   IntFieldType,
+                                   StringFieldType)
 
 
 logger = logging.getLogger(__name__)
@@ -56,6 +63,57 @@ def _find_httprequest(args):
     return request
 
 
+def _convert_legacy_field_type(legacy_type, field_info):
+    """Update field information for a legacy field type.
+
+    This takes a legacy field type (which in most cases are only compatible
+    with Python 2.x) and updates the provided field information dictionary
+    with modern information for the type of field.
+
+    It's important to be clear that the provided field information dictionary
+    *will* be modified. This avoids having to repeatedly convert the
+    information in the cases where this is used.
+
+    Args:
+        legacy_type (object or type):
+            The legacy field type. This can be one of :py:class:`unicode`,
+            :py:class:`bytes`, :py:class:`bool`, :py:class:`int`,
+            :py:class:`file`, :py:class:`list`, or :py:calss:`tuple`.
+
+        field_info (dict):
+            The field information dictionary to update.
+
+    Returns:
+        type:
+        The new subclass of :py:class:`BaseAPIFieldType` stored in the
+        dictionary.
+    """
+    new_type = None
+
+    if inspect.isclass(legacy_type):
+        if issubclass(legacy_type, (six.binary_type, six.text_type)):
+            new_type = StringFieldType
+        elif issubclass(legacy_type, bool):
+            new_type = BooleanFieldType
+        elif issubclass(legacy_type, int):
+            new_type = IntFieldType
+        elif legacy_type.__name__ == 'file':
+            # `file` doesn't exist in Python 3, so no module using that as a
+            # type will actually get far enough to define it. We're checking
+            # using the class name, which will help us mock this as well.
+            new_type = FileFieldType
+    elif type(legacy_type) in (list, tuple):
+        field_info['choices'] = tuple(legacy_type)
+        new_type = ChoiceFieldType
+
+    if new_type is None:
+        raise TypeError('%r is not a valid field type' % (legacy_type,))
+
+    field_info['type'] = new_type
+
+    return new_type
+
+
 def copy_webapi_decorator_data(from_func, to_func):
     """Copies and merges data from one decorated function to another.
 
@@ -212,9 +270,13 @@ def webapi_request_fields(required={}, optional={}, allow_unknown=False):
 
     .. code-block:: python
 
+        from djblets.webapi.decorators import webapi_request_fields
+        from djblets.webapi.fields import StringFieldType
+
+
         @webapi_request_fields(required={
             'name': {
-                'type': str,
+                'type': StringFieldType,
                 'description': 'The name of the object',
             }
         })
@@ -252,49 +314,25 @@ def webapi_request_fields(required={}, optional={}, allow_unknown=False):
 
             for fields_dict, is_required in ((required, True),
                                              (optional, False)):
-                for field_name, info in six.iteritems(fields_dict):
-                    field_type = info['type']
+                for field_name, field_info in six.iteritems(fields_dict):
+                    field_type_cls = field_info['type']
 
-                    if field_type is file:
-                        temp_fields = request.FILES
-                    else:
-                        temp_fields = request_fields
+                    if not hasattr(field_type_cls, 'clean_value'):
+                        field_type_cls = _convert_legacy_field_type(
+                            field_type_cls, field_info)
 
-                    value = temp_fields.get(field_name)
+                    field_type = field_type_cls(field_info)
+                    field_value = field_type.get_value_from_data(
+                        name=field_name,
+                        fields_data=request_fields,
+                        files_data=request.FILES)
 
-                    if value is not None:
-                        if type(field_type) in (list, tuple):
-                            # This is a multiple-choice. Make sure the value is
-                            # valid.
-                            if value not in field_type:
-                                invalid_fields[field_name] = [
-                                    '"%s" is not a valid value. Valid values '
-                                    'are: %s' % (
-                                        value,
-                                        ', '.join(['"%s"' % choice
-                                                   for choice in field_type])
-                                    )
-                                ]
-                        else:
-                            try:
-                                if issubclass(field_type, bool):
-                                    value = \
-                                        value in (1, '1', True, 'True', 'true')
-                                elif issubclass(field_type, int):
-                                    try:
-                                        value = int(value)
-                                    except ValueError:
-                                        invalid_fields[field_name] = [
-                                            '"%s" is not an integer' % value
-                                        ]
-                            except TypeError:
-                                # The field isn't a class type. This is a
-                                # coding error on the developer's side.
-                                raise TypeError(
-                                    '%r is not a valid field type'
-                                    % field_type)
-
-                        parsed_request_fields[field_name] = value
+                    if field_value is not None:
+                        try:
+                            parsed_request_fields[field_name] = \
+                                field_type.clean_value(field_value)
+                        except ValidationError as e:
+                            invalid_fields[field_name] = e.messages
                     elif is_required:
                         invalid_fields[field_name] = ['This field is required']
 
